@@ -91,7 +91,7 @@ void ActionManager::initPart(KLinkStatusPart* part)
     d->part = part;
     d->actionCollection = part->actionCollection();
 
-    QAction* action = 0;
+    KAction* action = 0;
 
     // *************** File menu *********************
 
@@ -164,6 +164,12 @@ void ActionManager::initTabWidget(TabWidgetSession* tabWidgetSession)
     connect(action, SIGNAL(triggered(bool) ), d->tabWidgetSession, SLOT(slotExportBrokenAsHTML()));
     action->setEnabled(false);
 
+    action  = new KAction(KIcon("document-save"), i18n("Create Site Map..."), this);
+    actionCollection()->addAction("file_create_site_map", action);
+    connect(action, SIGNAL(triggered(bool) ), d->tabWidgetSession, SLOT(slotCreateSiteMap()));
+    action->setEnabled(false);
+    
+
     // *************** View menu *********************
 
     //     this action must be in the tabwidget because the slot can't be connected to a particular sessionWidget
@@ -439,6 +445,7 @@ void ActionManager::updateGeneralActions(SessionStackedWidget* page)
 
     action("file_export_html_all")->setEnabled(!sw->isEmpty());
     action("file_export_html_broken")->setEnabled(!sw->isEmpty());
+    action("file_create_site_map")->setEnabled(!sw->isEmpty());
     action("html_fix_all")->setEnabled(!sw->isEmpty() && sw->stopped());
     action("find_unreferred_documents")->setEnabled(!sw->isEmpty() && sw->stopped());
 }
@@ -471,7 +478,7 @@ void ActionManager::slotGHNS()
     foreach(KNS::Entry* entry, entries) {
         // care only about installed ones
         if (entry->status() == KNS::Entry::Installed) {
-            foreach(QString file, entry->installedFiles()) {
+            foreach(const QString &file, entry->installedFiles()) {
                 KMimeType::Ptr mimeType = KMimeType::findByPath(file);
                 
                 kDebug(23100) << "File: " << file;
